// Import Data
forval y = 1/3 {
    import excel warn_nh.xls, sheet("`y'") firstrow allstring clear
	tempfile nh`y'
    save `nh`y''
}
*

use `nh1', clear
forval y = 2/3 {
    append using `nh`y''
}
*

g state = "NH"

// Work with Dates
replace DateWARNReceived = "7/8/2011" if DateWARNReceived == ///
	"7/8/2011  9/30/2011  10/3/2011"


g first_layoff_date = upper(trim(DateofLayoffClosure))

replace first_layoff_date = "9/3/2009" if first_layoff_date == ///
	"9/3/2009 - 2/28/2010                   3/29/2010-4/30/2010"
replace first_layoff_date = "11/20/2009" if first_layoff_date == ///
	"11/20/2009, 12/18/2009, 1/15/2010"
replace first_layoff_date = "11/22/2009" if first_layoff_date == ///
	"11/22/2009-11/28/2009     12/27/2009-1/2/2010"
replace first_layoff_date = "2/7/2010" if first_layoff_date == ///
	"2/7/2010 - 4/4/2010"
replace first_layoff_date = "2/12/2010" if first_layoff_date == ///
	"2/12/2010 - 5/2010"
replace first_layoff_date = "3/26/2010" if first_layoff_date == ///
	"3/26/10-7/13/10 LAYOFFS             6/30/10-7/23/10 CLOSE DATE"

// Chose second date since first date is year before notice
replace first_layoff_date = "8/8/2010" if first_layoff_date == ///
	"11/30/2009,  8/8/2010, 8/29/2010, 10/8/2010, 10/29/2010, 11/10/2010, 12/3/2010"
	
replace first_layoff_date = "8/30/2010" if first_layoff_date == ///	
	"DATE EXTENDED FROM 8/30/2010 TO 9/18/2010; DATE EXTENDED TO 10/13/2010; DATE EXTENDED TO 11/5/2010"
replace first_layoff_date = "8/16/2010" if first_layoff_date == ///
	"8/16/2010, 9/17/2010"
replace first_layoff_date = "12/8/2010" if first_layoff_date == ///
	"LAYOFF COMMENCING 12/8/2010                                               LAYOFF WILL CONTINUE THRU EARLY SEPTEMBER 2011"
replace first_layoff_date = "7/11/2011" if first_layoff_date == ///
	"7/11/2011 - 9/2/2011"
replace first_layoff_date = "8/31/2011" if first_layoff_date == ///
	"LAYOFFS COMPLETED BY 8/31/2011"
replace first_layoff_date = "9/15/2011" if first_layoff_date == ///
	"9/15/2011 - 12/31/2011"
replace first_layoff_date = "9/14/2011" if first_layoff_date == ///
	"9/14/2011                                   10/30/2011 (PART OF SEASONSAL SHUTDOWN)"
replace first_layoff_date = "9/30/2011" if first_layoff_date == "30SEP2011"
replace first_layoff_date = "12/1/2011" if first_layoff_date == ///
	"LAYOFFS BEGIN 12/1/2011 & EXPECT TO BE COMPLETED IN APPROX. 4 MONTHS"
replace first_layoff_date = "12/16/2011" if first_layoff_date == ///
	"CLOSING BEGINS 10/16/2011 & TERMINATION EFFECTIVE 12/16/2011"
replace first_layoff_date = "3/31/2012" if first_layoff_date == ///
	"3/31/2012-12/31/2012"
replace first_layoff_date = "3/5/2012" if first_layoff_date == ///
	"3/5/2012-5/2012"
replace first_layoff_date = "7/7/2012" if first_layoff_date == ///
	"AS EARLY AS 60 DAYS FROM RECEIPT OF NOTICE - APPROXIMATELY 7/7/2012"
replace first_layoff_date = "7/27/2012" if first_layoff_date == "27JUL2012"
replace first_layoff_date = "10/31/2013" if first_layoff_date == ///
	"10/31/2013, 11/30/2013 & 12/31/2013"
replace first_layoff_date = "8/7/2015" if first_layoff_date == ///
	"8/7/15, 8/14/15, 9/4/15, 10/9/15 & 3/31/16"
replace first_layoff_date = "6/30/2016" if first_layoff_date == ///
	"6/30/2016 12/31/2016"

g receive_date = date(DateWARNReceived,"MDY")
g layoff_date = date(first_layoff_date,"MDY")
format receive_date layoff_date %td


g firm_name = upper(trim(Company))
g workers_affected = real(NumberLaidOff)

g county_name = upper(trim(County))



// Location Flag
g flag_loc = .
replace flag_loc = 1 if county_name == "GRAFTON, BELKNAP, MERRIMACK, STRAFFORD"
replace flag_loc = 1 if county_name == "MERRIMACK / COOS"
replace flag_loc = 1 if county_name == "MERRIMACK, HILLSBOROUGH"
replace flag_loc = 1 if county_name == "MERRIMACK, ROCKINGHAM, HILLSBOROUGH"
replace flag_loc = 1 if county_name == "CHESHIRE, GRAFTON, MERRIMACK"


// Manual # of Workers Affected Fixes
g flag_affected = 0

replace workers_affected = 338 if ///
	NumberLaidOff == "338 regular 26 perdiem 25 temp parttime"
replace workers_affected = 212 if ///
	NumberLaidOff == "Nashua 126          Pelham 86"
replace workers_affected = 90 if NumberLaidOff == "5, 13, 16, 20, 32, 1, 3"

replace workers_affected = 150 if NumberLaidOff == "100-200"
replace flag_affected = 1 if NumberLaidOff == "100-200"
replace workers_affected = 55 if NumberLaidOff == "up to 55 "
replace flag_affected = 2 if NumberLaidOff == "up to 55 "

// Save Cleaned Data
keeporder receive_date layoff_date firm_name state county_name ///
    workers_affected flag_loc flag_affected

save nh_warn, replace
