// Import Data
foreach y in "1011" "1112" "1213" "1314" "1415" "1516" "1617" {
    
	import delimited va_warn_fy`y'.csv, delimiter(comma) clear
	
	cap ren company firm_name
	cap g announce_date = mdy(notice_m,notice_d,notice_y)
	cap g announce_date = date(noticedate,"MDY")
	cap g layoff_date = mdy(impact_m,impact_d,impact_y)
	cap g layoff_date = date(impactdate,"MDY")
	cap ren c_name firm_name
	
	cap ren employeesaffected workers_affected
	cap ren employees workers_affected
	cap ren l_city location
	
	cap g layoff_type = (closure=="Y")
	cap g layoff_type = (type=="Closure")
	replace layoff_type = layoff_type + 1 // layoff=1, close=2 
	
	keep announce_date layoff_date firm_name location layoff_type ///
	workers_affected
	
	tempfile va`y'
    save `va`y''
}
*

use `va1011', clear
foreach y in "1112" "1213" "1314" "1415" "1516" "1617" {
	append using `va`y''
}
*

g state = "VA"

format announce_date layoff_date %td

replace location = upper(trim(location))

// Fix Loc Typos & Other Matching Issues
replace location = substr(location,1,length(location)-4) if ///
    strpos(location,", VA") > 0
replace location = "ARLINGTON" if location == "ARLINGTON CO."
replace location = "ARLINGTON" if location == "DCA-ARLINGTON"
replace location = "CHESAPEAKE" if location == "CHESEAPEAKE"
replace location = "CHESTERFIELD" if location == "CHESTERFIELD COUNTY"
replace location = "CHRISTIANSBURG" if location == "CHRISTIANBURG"
replace location = "CROZET" if location == "CROZRT"
replace location = "FAIRFAX" if location == "FAIRFAIX"
replace location = "FAIRFAX" if location == "FORT BELVOIR (FAIRFAX COUNTY)"
replace location = "FORT BELVOIR" if location == "FT. BELVOIR"
replace location = "KINSALE" if location == "KINSDALE"
replace location = "LA CROSSE" if location == "LACROSSE"
replace location = "MANASSAS" if location == "MANASAS"
replace location = "MC LEAN" if location == "MCLEAN"
replace location = "NORFOLK" if location == "NORLFOLK"
replace location = "RICHMOND" if location == "RICHMOND,VA,"
replace location = "RICHMOND" if location == "RCIHMOND"
replace location = "RICHMOND & LYNCHBURG" if location == "RICHMON & LYNCHBURG"
replace location = "SANDSTON" if location == "SANDSON"
replace location = "SOUTH HILL" if location == "SOUT HILL"
replace location = "SPOTSYLVANIA" if location == "SPOTSYLVANIA COUNTY"
replace location = "VIRGINIA BEACH" if location == "VIRIGNIA BEACH"


// Match municipalities to counties
preserve
use va_muni_county_crosswalk, clear
drop if dup > 0
drop dup muni_county_same
tempfile va_cross
save `va_cross'
restore

ren location muni
merge m:1 state muni using `va_cross', keep(1 3)
ren muni location
ren _m merge1

// Now pick up some of the independent cities
preserve
use va_muni_county_crosswalk, clear
keep if dup > 0
keep if muni_county_same == 1
drop dup muni_county_same
duplicates tag state muni, g(dup1)
drop if dup1 > 0
drop dup1
ren county_name county_name2
tempfile va_cross2
save `va_cross2'
restore

ren location muni
merge m:1 state muni using `va_cross2', keep(1 3)
ren muni location

replace county_name = county_name2 if county_name == ""

// Cities/Counties that will be combined (because same name)
foreach n in "FAIRFAX" "ROANOKE" "MANASSAS" {
	replace county_name =  "`n'" if location == "`n'"
}
*

// Other Fixes
foreach n in "PRINCE WILLIAM" "HENRICO" "WASHINGTON" {
	replace county_name =  "`n'" if location == "`n'"
}
*
replace county_name = "YORK" if location == "TABB"
replace county_name = "FAIRFAX" if location == "SPRINGFIELD & NEWINGTON"
replace county_name = "DICKENSON" if location == "CLINTWOOD & NORA"
replace county_name = "PRINCE EDWARD" if location == "HAMPDEN-SYDNEY"
replace county_name = "ISLE OF WIGHT" if location == "SMITHFIELD"


// Location Flag
g flag_loc = 0
replace flag_loc = 1 if (location == "FAIRFAX & WOODBRIDGE" | ///
	location == "RICHMOND & LYNCHBURG" | ///
	location == "ABINGDON, CLINTWOOD & HAYSI" | ///
	location == "STONY CREEK & EMPORIA" | ///
	location == "ALEXANDRIA & QUANTICO" | ///
	location == "ALEXANDRIA, FA" | ///
	location == "HAMPTON & CHESAPEAKE" | ///
	location == "NEW KENT & RICHMOND" | ///
	location == "NORFOLK & PORTSMOUTH" | ///
	location == "NORFOLK & SUFFOLK" | ///
	location == "SUFFOLK & VIRGINIA BEACH" | ///
	location == "RICHMOND & GLEN ALLEN" | ///
	location == "SUFFOLK, NO")
replace flag_loc = 2 if (location == "STATEWIDE" | ///
    location == "MULTIPLE RETAIL LOCATIONS IN VA," | ///
	location == "CENTRAL" | ///
    location == "EASTERN" | ///
	location == "NORTHERN")
replace flag_loc = 3 if (location == "HOFFMAN ESTATES" | ///
    location == "FORT EUSTIS & FORT STORY" | ///
	location == "LANGLEY AFB" | ///
	location == "LANGLEY-EUSTIS, VI" | ///
	location == "MCFALL")

drop if firm_name == "SONOCO" // No workers affected
	
// Save Cleaned Data	
keeporder announce_date layoff_date firm_name state location workers_affected ///
   county_name layoff_type flag_loc


save va_warn, replace
